@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  */
 
@@ -35,9 +35,14 @@
 #define CAPPLET_COMMENT_ENTRY_WIDGET_NAME "session_properties_comment_entry"
 #define CAPPLET_BROWSE_WIDGET_NAME        "session_properties_browse_button"
 
-
 #define GSM_APP_DIALOG_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GSM_TYPE_APP_DIALOG, GsmAppDialogPrivate))
 
+#ifdef __GNUC__
+#define UNUSED_VARIABLE __attribute__ ((unused))
+#else
+#define UNUSED_VARIABLE
+#endif
+
 struct GsmAppDialogPrivate
 {
         GtkWidget *name_entry;
@@ -473,7 +478,7 @@ gsm_app_dialog_run (GsmAppDialog  *dialog,
                 GError     *error;
                 char      **argv;
                 int         argc;
-                gboolean    changed;
+                gboolean   UNUSED_VARIABLE changed;
 
                 name = gsm_app_dialog_get_name (GSM_APP_DIALOG (dialog));
                 exec = gsm_app_dialog_get_command (GSM_APP_DIALOG (dialog));
