@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  * Authors: William Jon McCann <mccann@jhu.edu>
  *
@@ -193,7 +193,7 @@ handle_alarm_notify_event (GSIdleMonitor         *monitor,
                 return;
         }
 
-        g_debug ("Watch %d fired, idle time = %lld",
+        g_debug ("Watch %d fired, idle time = %ld",
                  watch->id,
                  _xsyncvalue_to_int64 (alarm_event->counter_value));
 
@@ -450,22 +450,22 @@ _xsync_alarm_set (GSIdleMonitor      *monitor,
 
         attr.trigger.test_type = XSyncPositiveTransition;
         if (watch->xalarm_positive != None) {
-                g_debug ("GSIdleMonitor: updating alarm for positive transition wait=%lld",
+                g_debug ("GSIdleMonitor: updating alarm for positive transition wait=%ld",
                          _xsyncvalue_to_int64 (attr.trigger.wait_value));
                 XSyncChangeAlarm (GDK_DISPLAY_XDISPLAY(gdk_display_get_default()), watch->xalarm_positive, flags, &attr);
         } else {
-                g_debug ("GSIdleMonitor: creating new alarm for positive transition wait=%lld",
+                g_debug ("GSIdleMonitor: creating new alarm for positive transition wait=%ld",
                          _xsyncvalue_to_int64 (attr.trigger.wait_value));
                 watch->xalarm_positive = XSyncCreateAlarm (GDK_DISPLAY_XDISPLAY(gdk_display_get_default()), flags, &attr);
         }
 
         attr.trigger.test_type = XSyncNegativeTransition;
         if (watch->xalarm_negative != None) {
-                g_debug ("GSIdleMonitor: updating alarm for negative transition wait=%lld",
+                g_debug ("GSIdleMonitor: updating alarm for negative transition wait=%ld",
                          _xsyncvalue_to_int64 (attr.trigger.wait_value));
                 XSyncChangeAlarm (GDK_DISPLAY_XDISPLAY(gdk_display_get_default()), watch->xalarm_negative, flags, &attr);
         } else {
-                g_debug ("GSIdleMonitor: creating new alarm for negative transition wait=%lld",
+                g_debug ("GSIdleMonitor: creating new alarm for negative transition wait=%ld",
                          _xsyncvalue_to_int64 (attr.trigger.wait_value));
                 watch->xalarm_negative = XSyncCreateAlarm (GDK_DISPLAY_XDISPLAY(gdk_display_get_default()), flags, &attr);
         }
