@@ -15,8 +15,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301, USA.
  */
 
 #include <config.h>
@@ -29,11 +29,15 @@
 #include <glib.h>
 #include <gio/gio.h>
 
-#include <mateconf/mateconf-client.h>
-
 #include "gsm-autostart-app.h"
 #include "gsm-util.h"
 
+#ifdef __GNUC__
+#define UNUSED_VARIABLE __attribute__ ((unused))
+#else
+#define UNUSED_VARIABLE
+#endif
+
 enum {
         AUTOSTART_LAUNCH_SPAWN = 0,
         AUTOSTART_LAUNCH_ACTIVATE
@@ -43,8 +47,9 @@ enum {
         GSM_CONDITION_NONE          = 0,
         GSM_CONDITION_IF_EXISTS     = 1,
         GSM_CONDITION_UNLESS_EXISTS = 2,
-        GSM_CONDITION_MATE         = 3,
-        GSM_CONDITION_UNKNOWN       = 4
+        GSM_CONDITION_MATE          = 3,
+        GSM_CONDITION_GSETTINGS     = 4,
+        GSM_CONDITION_UNKNOWN       = 5
 };
 
 #define GSM_SESSION_CLIENT_DBUS_INTERFACE "org.mate.SessionClient"
@@ -62,7 +67,7 @@ struct _GsmAutostartAppPrivate {
         gboolean              autorestart;
 
         GFileMonitor         *condition_monitor;
-        guint                 condition_notify_id;
+        GSettings            *condition_settings;
 
         int                   launch_type;
         GPid                  pid;
@@ -159,6 +164,8 @@ parse_condition_string (const char *condition_string,
                 kind = GSM_CONDITION_UNLESS_EXISTS;
         } else if (!g_ascii_strncasecmp (condition_string, "MATE", len)) {
                 kind = GSM_CONDITION_MATE;
+        } else if (!g_ascii_strncasecmp (condition_string, "GSettings", len)) {
+                kind = GSM_CONDITION_GSETTINGS;
         } else {
                 key = NULL;
                 kind = GSM_CONDITION_UNKNOWN;
@@ -238,10 +245,9 @@ unless_exists_condition_cb (GFileMonitor     *monitor,
 }
 
 static void
-mateconf_condition_cb (MateConfClient *client,
-                    guint        cnxn_id,
-                    MateConfEntry  *entry,
-                    gpointer     user_data)
+gsettings_condition_cb (GSettings  *settings,
+                        const char *key,
+                        gpointer    user_data)
 {
         GsmApp                 *app;
         GsmAutostartAppPrivate *priv;
@@ -253,10 +259,7 @@ mateconf_condition_cb (MateConfClient *client,
 
         priv = GSM_AUTOSTART_APP (app)->priv;
 
-        condition = FALSE;
-        if (entry->value != NULL && entry->value->type == MATECONF_VALUE_BOOL) {
-                condition = mateconf_value_get_bool (entry->value);
-        }
+        condition = g_settings_get_boolean (settings, key);
 
         g_debug ("GsmAutostartApp: app:%s condition changed condition:%d",
                  gsm_app_peek_id (app),
@@ -269,24 +272,68 @@ mateconf_condition_cb (MateConfClient *client,
         }
 }
 
+static gboolean
+setup_gsettings_condition_monitor (GsmAutostartApp *app,
+                                   const char      *key)
+{
+        GSettings *settings;
+        const char * const *schemas;
+        char **elems;
+        gboolean schema_exists;
+        guint i;
+        gboolean retval;
+        char *signal;
+
+        elems = g_strsplit (key, " ", 2);
+        if (elems == NULL)
+                return FALSE;
+        if (elems[0] == NULL || elems[1] == NULL) {
+                g_strfreev (elems);
+                return FALSE;
+        }
+
+        schemas = g_settings_list_schemas ();
+        schema_exists = FALSE;
+        for (i = 0; schemas[i] != NULL; i++) {
+                if (g_str_equal (schemas[i], elems[0])) {
+                        schema_exists = TRUE;
+                        break;
+                }
+        }
+
+        if (schema_exists == FALSE)
+                return FALSE;
+
+        settings = g_settings_new (elems[0]);
+        retval = g_settings_get_boolean (settings, elems[1]);
+
+        signal = g_strdup_printf ("changed::%s", elems[1]);
+        g_signal_connect (G_OBJECT (settings), signal,
+                          G_CALLBACK (gsettings_condition_cb), app);
+        g_free (signal);
+
+        app->priv->condition_settings = settings;
+
+        g_strfreev (elems);
+
+        return retval;
+}
+
 static void
 setup_condition_monitor (GsmAutostartApp *app)
 {
         guint    kind;
         char    *key;
         gboolean res;
-        gboolean disabled;
+        gboolean UNUSED_VARIABLE disabled;
 
         if (app->priv->condition_monitor != NULL) {
                 g_file_monitor_cancel (app->priv->condition_monitor);
         }
 
-        if (app->priv->condition_notify_id > 0) {
-                MateConfClient *client;
-                client = mateconf_client_get_default ();
-                mateconf_client_notify_remove (client,
-                                            app->priv->condition_notify_id);
-                app->priv->condition_notify_id = 0;
+        if (app->priv->condition_settings != NULL) {
+                g_object_unref (app->priv->condition_settings);
+                app->priv->condition_settings = NULL;
         }
 
         if (app->priv->condition_string == NULL) {
@@ -344,26 +391,9 @@ setup_condition_monitor (GsmAutostartApp *app)
                 g_object_unref (file);
                 g_free (file_path);
         } else if (kind == GSM_CONDITION_MATE) {
-                MateConfClient *client;
-                char        *dir;
-
-                client = mateconf_client_get_default ();
-                g_assert (MATECONF_IS_CLIENT (client));
-
-                disabled = !mateconf_client_get_bool (client, key, NULL);
-
-                dir = g_path_get_dirname (key);
-
-                mateconf_client_add_dir (client,
-                                      dir,
-                                      MATECONF_CLIENT_PRELOAD_NONE, NULL);
-                g_free (dir);
-
-                app->priv->condition_notify_id = mateconf_client_notify_add (client,
-                                                                          key,
-                                                                          mateconf_condition_cb,
-                                                                          app, NULL, NULL);
-                g_object_unref (client);
+                disabled = !setup_gsettings_condition_monitor (app, key);
+        } else if (kind == GSM_CONDITION_GSETTINGS) {
+                disabled = !setup_gsettings_condition_monitor (app, key);
         } else {
                 disabled = TRUE;
         }
@@ -553,6 +583,11 @@ gsm_autostart_app_dispose (GObject *object)
                 priv->condition_string = NULL;
         }
 
+        if (priv->condition_settings) {
+                g_object_unref (priv->condition_settings);
+                priv->condition_settings = NULL;
+        }
+
         if (priv->desktop_file) {
                 egg_desktop_file_free (priv->desktop_file);
                 priv->desktop_file = NULL;
@@ -641,12 +676,16 @@ is_conditionally_disabled (GsmApp *app)
                 file_path = g_build_filename (g_get_user_config_dir (), key, NULL);
                 disabled = g_file_test (file_path, G_FILE_TEST_EXISTS);
                 g_free (file_path);
-        } else if (kind == GSM_CONDITION_MATE) {
-                MateConfClient *client;
-                client = mateconf_client_get_default ();
-                g_assert (MATECONF_IS_CLIENT (client));
-                disabled = !mateconf_client_get_bool (client, key, NULL);
-                g_object_unref (client);
+        } else if (kind == GSM_CONDITION_MATE && priv->condition_settings != NULL) {
+                char **elems;
+                elems = g_strsplit (key, " ", 2);
+                disabled = !g_settings_get_boolean (priv->condition_settings, elems[1]);
+                g_strfreev (elems);
+        } else if (kind == GSM_CONDITION_GSETTINGS && priv->condition_settings != NULL) {
+                char **elems;
+                elems = g_strsplit (key, " ", 2);
+                disabled = !g_settings_get_boolean (priv->condition_settings, elems[1]);
+                g_strfreev (elems);
         } else {
                 disabled = TRUE;
         }
