@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  */
 
@@ -31,8 +31,6 @@
 #include <gtk/gtk.h>
 #include <gdk/gdkx.h>
 
-#include <mateconf/mateconf-client.h>
-
 #include "gsm-inhibit-dialog.h"
 #include "gsm-store.h"
 #include "gsm-client.h"
@@ -403,8 +401,10 @@ get_pixmap_for_window (Window window)
         Picture                  src_picture;
         Picture                  dst_picture;
         gboolean                 has_alpha;
+#if 0
         int                      x;
         int                      y;
+#endif
         int                      width;
         int                      height;
 
@@ -412,8 +412,10 @@ get_pixmap_for_window (Window window)
 
         format = XRenderFindVisualFormat (GDK_DISPLAY_XDISPLAY(gdk_display_get_default()), attr.visual);
         has_alpha = (format->type == PictTypeDirect && format->direct.alphaMask);
+#if 0
         x = attr.x;
         y = attr.y;
+#endif
         width = attr.width;
         height = attr.height;
 
