@@ -27,6 +27,7 @@
 #include <string.h>
 #include <unistd.h>
 #include <errno.h>
+#include <time.h>
 
 #include <glib/gi18n.h>
 #include <glib.h>
@@ -44,7 +45,6 @@
 #include "gsm-consolekit.h"
 #ifdef HAVE_SYSTEMD
 #include "gsm-systemd.h"
-#include <systemd/sd-daemon.h>
 #endif
 #include "gsm-util.h"
 #include "gsm-manager.h"
@@ -67,6 +67,27 @@ static gboolean failsafe = FALSE;
 static gboolean show_version = FALSE;
 static gboolean debug = FALSE;
 
+static gboolean
+initialize_gsettings (void)
+{
+	GSettings* settings;
+	time_t now = time (0);
+	gboolean ret;
+
+	settings = g_settings_new (GSM_SCHEMA);
+
+	if (!settings)
+		return FALSE;
+
+	ret = g_settings_set_int (settings, "session-start", now);
+
+	g_settings_sync ();
+
+	g_object_unref (settings);
+
+        return ret;
+}
+	
 static void on_bus_name_lost(DBusGProxy* bus_proxy, const char* name, gpointer data)
 {
 	g_warning("Lost name on bus: %s, exiting", name);
@@ -271,7 +292,7 @@ static void maybe_load_saved_session_apps(GsmManager* manager)
 	gboolean is_login;
 
 #ifdef HAVE_SYSTEMD
-	if (sd_booted() > 0) {
+	if (LOGIND_RUNNING()) {
 		systemd = gsm_get_systemd();
 		session_type = gsm_systemd_get_current_session_type(systemd);
 		is_login = g_strcmp0 (session_type, GSM_SYSTEMD_SESSION_TYPE_LOGIN_WINDOW) == 0;
@@ -505,6 +526,13 @@ int main(int argc, char** argv)
 	 */
 	gsm_util_setenv("MATE_DESKTOP_SESSION_ID", "this-is-deprecated");
 
+	/*
+	 * Make sure gsettings is set up correctly.  If not, then bail.
+	 */
+
+	if (initialize_gsettings () != TRUE)
+		exit (1);
+
 	client_store = gsm_store_new();
 
 	xsmp_server = gsm_xsmp_server_new(client_store);
